require_relative 'player'
require_relative 'die'
require_relative 'game_turn'
require_relative 'treasure_trove'


module StudioGame

	class Game

		attr_accessor :title

		def initialize(title)
			@title = title
			@players = []
		end

		def add_player(player)
			@players.push(player)
			# puts @players
		end

		def play(rounds)
			puts "Let's play Knuckleheads!"

			puts "\nLooks like we have #{@players.size} players this game:"
			@players.each do |player|
				formatted_name = player.name.ljust(20, '.')
				puts "#{formatted_name} #{player.health} HP"
			end

			treasures = TreasureTrove::TREASURES
			puts "\nThere are #{treasures.count} treasures in the Treasure Trove:"

			treasures.each do |treasure|
				puts "A #{treasure.name} is worth #{treasure.points} HP"
			end

			1.upto(rounds) do |round|
				puts "\nRound #{round}:"

				@players.each do |player|      
					GameTurn.take_turn(player)
					puts "#{player}"
					puts "\n"
				end
			end

			
		end

		def print_high_scores(player)
			formatted_name = player.name.ljust(20, '.')
			"#{formatted_name} #{player.score}"
		end

		def print_stats
			puts "\n*** Knucklehead Statistics ***"

			strong_players, wimpy_players = @players.partition { |player| player.strong? }

			puts "\n#{strong_players.count} strong players:"

			strong_players.each do |player|
				puts "#{player.name} (#{player.health})"
			end

			puts "\n#{wimpy_players.count} wimpy players:"

			wimpy_players.each do |player|
				puts "#{player.name} (#{player.health})"
			end

			puts "\n#{title} Final Ranking:"
			@players.sort.each do |player|
				puts print_high_scores(player)
			end

			@players.each do |player|
				puts "\n#{player.name}'s Point Breakdown"
				player.each_found_treasure do |treasure|
					puts "+ #{treasure.points} total #{treasure.name} points"
				end
				puts "= #{player.points} Treasure Points"
				puts "+ #{player.health} HP"
				puts "= #{player.score} Total Game Points"
			end

		end

		def print_name_and_health(player)
			puts "#{player.name} (#{player.health}"
		end

		def load_players(file)
			File.readlines(file).each do |line|
				add_player(Player.from_csv(line))
			end
		end

		def save_high_scores(file="high_scores_revised.txt")
			
			File.open(file, "w") do |file|
				file.puts "#{@title} High Score"

				@players.sort.each do |player|
					file.puts print_high_scores(player)
				end

			end
		end

	end

end




















